@@ -614,11 +614,13 @@ dw32_code_recursive (Dw32Info *info)
 
 /*  ja:コード解析
        info,イメージ情報構造体
+       proc,TRUE:関数解析を行う
      linear,TRUE:線形解析を行う
     referer,TRUE:データ参照解析を行う
        data,TRUE:データ領域解析を行う                                       */
 void
 dw32_code_parse (Dw32Info       *info,
+                 const gboolean  proc,
                  const gboolean  linear,
                  const gboolean  referer,
                  const gboolean  data)
@@ -656,6 +658,26 @@ dw32_code_parse (Dw32Info       *info,
   g_fprintf (stderr, "Recursive Analyse\n");
   dw32_code_recursive (info);
   checked = g_malloc0 (info->size * sizeof (gboolean));
+  if (proc)
+    {
+      /* ja:関数の先頭と思われるコードを探す */
+      g_fprintf (stderr, "Procedure Analyse\n");
+      for (i = 0; i < info->size; i++)
+        if (info->image[i] == 0x55 && info->status[i] == DW32_STAT_UNKNOWN
+                        && !checked[i] && dw32_code_line (info, i, checked))
+          {
+            if (dw32_code_subroutine (info, i, FALSE))
+              {
+                g_fprintf (stderr, "%08x/%08"G_GSIZE_MODIFIER"x Procedure\n",
+                                                                i, info->size);
+                dw32_code_recursive (info);
+              }
+            else
+              {
+                dw32_code_eraser (info, i);
+              }
+          }
+    }
   if (linear)
     {
       /* ja:未定部分のコード化を試みる */
