@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,13 +18,6 @@
 #include "slwga.h"
 
 
-/* SLIsGenuineLocal ordinal = 228, argument = 12 */
-static gboolean slwga_SLIsGenuineLocal (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_slwga_exports[] = {
-{12,  228, "SLIsGenuineLocal", slwga_SLIsGenuineLocal},
-{ 0,    0, NULL,               NULL}};
+{12, 228, "SLIsGenuineLocal", NULL},
+{G_MAXINT, 0, NULL, NULL}};
